ChannelBinding

Enum ChannelBinding 

pub enum ChannelBinding {
    None,
    Unsupported,
    TlsUnique(Vec<u8>),
    TlsExporter(Vec<u8>),
}
Channel binding configuration.

Variants



None

No channel binding data.



Unsupported

Advertise that the client does not think the server supports channel binding.



TlsUnique(Vec<u8>)

p=tls-unique channel binding data (for TLS 1.2).



TlsExporter(Vec<u8>)

p=tls-exporter channel binding data (for TLS 1.3).

Implementations

Source

impl ChannelBinding

pub fn header(&self) -> &[u8]

Return the gs2 header for this channel binding mechanism.

pub fn data(&self) -> &[u8]

Return the channel binding data for this channel binding mechanism.

pub fn supports(&self, mechanism: &str) -> bool

Checks whether this channel binding mechanism is supported.